@@ -1,7 +1,13 @@
+pub mod algorithms;
 pub mod indieauth;
 pub mod link_rel;
+pub mod micropub;
 pub mod webmention;
 
+use shadow_rs::shadow;
+
+shadow!(build);
+
 #[cfg(test)]
 mod test;
 
@@ -28,16 +34,17 @@ impl PartialEq for Error {
     }
 }
 
-static APP_USER_AGENT: &str = concat!(env!("CARGO_PKG_NAME"), "-rs/", env!("CARGO_PKG_VERSION"),);
+static IN_BUILT_APP_USER_AGENT: &str =
+    concat!(env!("CARGO_PKG_NAME"), "-rs/", env!("CARGO_PKG_VERSION"));
 
 /// Represents the base client interface for IndieWeb activity.
 pub trait IConfiguration {
     /// Define the base request.
     fn request(&self, reason: Option<String>) -> reqwest::Client {
-        let agent = if APP_USER_AGENT == self.user_agent() {
-            APP_USER_AGENT.to_owned()
+        let agent = if IN_BUILT_APP_USER_AGENT == self.user_agent() {
+            IN_BUILT_APP_USER_AGENT.to_owned() + "/-git" + build::COMMIT_HASH
         } else {
-            format!("{} {}", self.user_agent(), APP_USER_AGENT)
+            format!("{} {}", self.user_agent(), IN_BUILT_APP_USER_AGENT)
         };
 
         reqwest::Client::builder()
@@ -55,7 +62,7 @@ pub trait IConfiguration {
 
     /// The agent string to use when making out-going requests.
     fn user_agent(&self) -> &str {
-        APP_USER_AGENT
+        IN_BUILT_APP_USER_AGENT
     }
 }
 
